import React, { Fragment } from 'react';
import { shape, string, any, arrayOf, object } from 'prop-types';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var MultiSourceImage = function MultiSourceImage(_ref) {
  var _ref$sources = _ref.sources,
      defaultSource = _ref$sources.defaultSource,
      formats = _ref$sources.formats,
      _ref$mediaMapping = _ref.mediaMapping,
      mediaMapping = _ref$mediaMapping === void 0 ? {} : _ref$mediaMapping,
      alt = _ref.alt,
      _ref$backend = _ref.backend,
      backend = _ref$backend === void 0 ? '' : _ref$backend,
      children = _ref.children,
      _ref$ignore = _ref.ignore,
      ignore = _ref$ignore === void 0 ? [] : _ref$ignore,
      props = _objectWithoutPropertiesLoose(_ref, ["sources", "mediaMapping", "alt", "backend", "children", "ignore"]);

  return /*#__PURE__*/React.createElement("picture", null, Object.keys(formats).map(function (formatType, index) {
    return Object.values(formats[formatType]).sort(function (a, b) {
      if (a.mime === b.mime) {
        return 0;
      }

      if (a.mime === 'image/webp') {
        return -1;
      }

      if (b.mime === 'image/webp') {
        return 1;
      }

      return 0;
    }).map(function (format) {
      if (ignore.includes(format.mime)) {
        return null;
      }

      return /*#__PURE__*/React.createElement(Fragment, {
        key: index
      }, /*#__PURE__*/React.createElement("source", {
        media: mediaMapping[formatType],
        type: format.mime,
        srcSet: "" + backend + format.url
      }));
    });
  }), /*#__PURE__*/React.createElement("img", _extends({
    src: "" + backend + defaultSource.url,
    alt: alt
  }, props), children));
};

var imgShape = shape(_extends({
  url: string.isRequired,
  mime: string.isRequired
}, any));
MultiSourceImage.propTypes = _extends({
  sources: shape({
    defaultSource: imgShape.isRequired,
    formats: shape({
      large: arrayOf(imgShape),
      medium: arrayOf(imgShape),
      small: arrayOf(imgShape),
      thumbnail: arrayOf(imgShape)
    })
  }).isRequired,
  alt: string.isRequired,
  style: object,
  backend: string,
  className: string,
  ignore: arrayOf(string)
}, any);

export default MultiSourceImage;
//# sourceMappingURL=index.modern.js.map
